Web Application
===============

Since v0.12, Papis ships with an experimental, simple yet handy web application.

You can start the web application by issuing the following command

::

   papis serve --port 8181 --host localhost

Then input the following url in your browser

::

   http://localhost:8181

This web application can be useful if you intend to read access to your
documents from a tablet or from another computer.

Further documentation will be available soon, but bear in mind
that this web application is experimental, bug reports and
suggestions are highly appreciated.
